@@ -4,7 +4,8 @@ import os
 import sys
 import warnings
 import logging
-import numpy as np
+from cri_simulations.config import *
+
 #warnings.filterwarnings('error')
 
 def text2script(cmd_str):
@@ -67,23 +68,6 @@ class fpga_compiler:
 
     """
 
-    # OP code to read/write to hbm vie PCie
-    #HBM_OP_RW = '02' + 28 * '00'
-
-    PTR_ADDR_BITS = 23  # HBM row address
-    PTR_LEN_BITS = 9  # (8 connections/row x 2^9 rows = 2^12 = 4K connections max)
-    AXN_BASE_ADDR = 0  # axon pointer start address
-    NRN_BASE_ADDR = 2 ** 14  # neuron pointer start address (2^17 axons / 8 axon pointers/row = 2^14 rows max)
-    SYN_BASE_ADDR = 2 ** 15  # (2^17 neurons / 8 neuron pointers/row = 2^14 rows max -> 2^14+2^14=2^15)
-
-    SYN_ADDR_BITS = 13  # each synapse: [31:29]=OpCode  [28:16]=address, [15:0]=weight (1 sign + 15 value, fixed-point)
-    SYN_WEIGHT_BITS = 16
-    SYN_OP_BITS = 3
-
-    HBM_WRITE_CMD = 'sudo adxdma_dmadump wb 0 0 '
-
-    WRITE = '01' + 63 * '00'
-
     def __init__(self, data, N_neurons, outputs, coreID = 0):
         '''
         Creates the FPGA Compiler object. Populates spike packets in synapses.
@@ -122,6 +106,10 @@ class fpga_compiler:
             end = data[1][row][col][1] + 1
             finished = False
             for r in data[2][start:end]:
+                #if r[3] == (0,0,0) and n <= len(outputs):
+                #    r[3] = (1, neuronIdx)
+                #    finished = True
+                #    break
                 for i in range(len(r)):
                     if r[i] == (0, 0, 0) and n <= len(outputs):
                         r[i] = (1, neuronIdx)
@@ -139,6 +127,7 @@ class fpga_compiler:
                     if n > N_neurons:
                         logging.info('neuron pointer index is greater than specified number of internal neurons, a spike entry will not be assigned to remaining neuron pointer')
                     else:
+
                          errors+=1
                          logging.error('neuron pointer index: '+ str(n) +' could not be assigned a spike entry')
 
@@ -172,8 +161,8 @@ class fpga_compiler:
             cmd = ''
             for p in d:
                 decimal_addr = int(
-                    np.binary_repr(p[1] - p[0], self.PTR_LEN_BITS) + np.binary_repr(p[0] + self.SYN_BASE_ADDR,
-                                                                                    self.PTR_ADDR_BITS), 2)
+                    np.binary_repr(p[1] - p[0], PTR_LEN_BITS) + np.binary_repr(p[0] + SYN_BASE_ADDR,
+                                                                                    PTR_ADDR_BITS), 2)
 
                 cmd += '{:0{width}x}'.format(decimal_addr, width=8)
 
@@ -235,13 +224,13 @@ class fpga_compiler:
                 #print(d)
                 #print(p)
                 cmd += '{:0{width}x}'.format(
-                    int(np.binary_repr(p[1] - p[0], self.PTR_LEN_BITS) + np.binary_repr(p[0] + self.SYN_BASE_ADDR,
-                                                                                        self.PTR_ADDR_BITS), 2),
+                    int(np.binary_repr(p[1] - p[0], PTR_LEN_BITS) + np.binary_repr(p[0] + SYN_BASE_ADDR,
+                                                                                        PTR_ADDR_BITS), 2),
                     width=8)
 
 
             # append HBM write opcode and address
-            cmd = self.HBM_OP_RW + '{:0{width}x}'.format(0x800000 + self.NRN_BASE_ADDR + r, width=6) + cmd
+            cmd = self.HBM_OP_RW + '{:0{width}x}'.format(0x800000 + NRN_BASE_ADDR + r, width=6) + cmd
 
             # append command to complete script list
             if simDump:
@@ -278,19 +267,19 @@ class fpga_compiler:
                 if w[0] == 0:
                     # [31] = 0 for internal connections and 1 for external connections, [30:29] = unused for single core
                     # TODO: how do I know if a given synapse is an internal or external connection?
-                    cmd += '{:0{width}x}'.format(int(np.binary_repr( 0, self.SYN_OP_BITS) + np.binary_repr(int(w[1]), self.SYN_ADDR_BITS) + np.binary_repr(int(w[2]),self.SYN_WEIGHT_BITS), 2),width=8)
+                    cmd += '{:0{width}x}'.format(int(np.binary_repr( 0, SYN_OP_BITS) + np.binary_repr(int(w[1]), SYN_ADDR_BITS) + np.binary_repr(int(w[2]),SYN_WEIGHT_BITS), 2),width=8)
                 #TODO: looks like this format is out of date, it should be the same as the above format. It may not be hyper critical
                 elif w[0] == 1:
                     #spike = str(w[0]) + 15 * '0'
                     spike = 16 * '0'
-                    addr = np.binary_repr(w[1], self.SYN_ADDR_BITS)
+                    addr = np.binary_repr(w[1], SYN_ADDR_BITS)
                     #cmd += '{:0{width}x}'.format(int(spike + addr, 2), width=8)
-                    cmd += '{:0{width}x}'.format(int(np.binary_repr( 4, self.SYN_OP_BITS) + 12*'0' + np.binary_repr(w[1],17), 2),width=8)
+                    cmd += '{:0{width}x}'.format(int(np.binary_repr( 4, SYN_OP_BITS) + 12*'0' + np.binary_repr(w[1],17), 2),width=8)
 
 
 
             # append HBM write opcode and address
-            cmd = self.HBM_OP_RW + '{:0{width}x}'.format(0x800000 + self.SYN_BASE_ADDR + r, width=6) + cmd
+            cmd = self.HBM_OP_RW + '{:0{width}x}'.format(0x800000 + SYN_BASE_ADDR + r, width=6) + cmd
             # append command to complete script list
             if simDump:
                 dump.append(cmd)
@@ -441,7 +430,7 @@ class fpga_compiler:
         with open(fname + '_script.txt', 'a') as f2:
             f2.writelines('echo "Configuring Axon Pointers... "\n')
 
-        cmd = self.HBM_WRITE_CMD
+        cmd = HBM_WRITE_CMD
 
         l = 0
         axon_ptr_length = len(axon_ptrs.split('\n'))
@@ -456,7 +445,7 @@ class fpga_compiler:
         with open(fname + '_script.txt', 'a') as f2:
             f2.writelines('echo "Configuring Neuron Pointers... "\n')
 
-        cmd = self.HBM_WRITE_CMD
+        cmd = HBM_WRITE_CMD
 
         l = 0
         neuron_ptr_length = len(neuron_ptrs.split('\n'))
@@ -472,7 +461,7 @@ class fpga_compiler:
         with open(fname + '_script.txt', 'a') as f2:
             f2.writelines('echo "Configuring Synapses... "\n')
 
-        cmd = self.HBM_WRITE_CMD
+        cmd = HBM_WRITE_CMD
 
         l = 0
         syn_length = len(synapses.split('\n'))
